======
mimirs
======

Installation
------------

To install mimirs, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install mimirs

Links
-----

* `Download <https://pypi.org/project/mimirs/#files>`_
